import type { IDS, PageQuery, PageResult } from '#/api/common';
import type { EquImportParam, EquVO } from '#/api/eims/equ/model';

import { commonExport, ContentTypeEnum } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  equExport = '/eims/equ/export',
  equImport = '/eims/equ/importData',
  equList = '/eims/equ/list',
  root = '/eims/equ',
  userImportTemplate = '/eims/equ/importTemplate'
}

/**
 * 查询【设备台账】列表
 * @param query
 * @returns {*}
 */

export function listEqu(params?: PageQuery) {
  return requestClient.get<PageResult<EquVO>>(Api.equList, { params });
}

/**
 * 查询【设备台账】详细
 * @param equId
 */
export function getEqu(equId: any) {
  return requestClient.get<EquVO>(`${Api.root}/${equId}`);
}

/**
 * 新增【设备台账】
 * @param data
 */
export function addEqu(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改【设备台账】
 * @param data
 */
export function updateEqu(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除【设备台账】
 * @param equIds
 */
export function delEqu(equIds: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${equIds}`);
}

/**
 * 导出【设备台账】
 * @param data
 */
export function equExport(data: any) {
  return commonExport(Api.equExport, data);
}

/**
 * 从excel导入设备
 * @param data
 * @returns void
 */
export function equImportData(data: EquImportParam) {
  return requestClient.post<{ code: number; msg: string }>(Api.equImport, data, {
    headers: {
      'Content-Type': ContentTypeEnum.FORM_DATA
    },
    isTransformResponse: false
  });
}

/**
 * 下载导入模板
 * @returns blob
 */
export function downloadImportTemplate() {
  return requestClient.post<Blob>(
    Api.userImportTemplate,
    {},
    {
      isTransformResponse: false,
      responseType: 'blob'
    }
  );
}
